package com.ruoyi.mall.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.MallImgShowMapper;
import com.ruoyi.mall.domain.MallImgShow;
import com.ruoyi.mall.service.IMallImgShowService;

/**
 * 小程序图片展示Service业务层处理
 * 
 * @author ruoyi
 * @date 2022-12-07
 */
@Service
public class MallImgShowServiceImpl implements IMallImgShowService 
{
    @Autowired
    private MallImgShowMapper mallImgShowMapper;

    /**
     * 查询小程序图片展示
     * 
     * @param id 小程序图片展示主键
     * @return 小程序图片展示
     */
    @Override
    public MallImgShow selectMallImgShowById(Long id)
    {
        return mallImgShowMapper.selectMallImgShowById(id);
    }

    /**
     * 查询小程序图片展示列表
     * 
     * @param mallImgShow 小程序图片展示
     * @return 小程序图片展示
     */
    @Override
    public List<MallImgShow> selectMallImgShowList(MallImgShow mallImgShow)
    {
        return mallImgShowMapper.selectMallImgShowList(mallImgShow);
    }

    /**
     * 新增小程序图片展示
     * 
     * @param mallImgShow 小程序图片展示
     * @return 结果
     */
    @Override
    public int insertMallImgShow(MallImgShow mallImgShow)
    {
        return mallImgShowMapper.insertMallImgShow(mallImgShow);
    }

    /**
     * 修改小程序图片展示
     * 
     * @param mallImgShow 小程序图片展示
     * @return 结果
     */
    @Override
    public int updateMallImgShow(MallImgShow mallImgShow)
    {
        return mallImgShowMapper.updateMallImgShow(mallImgShow);
    }

    /**
     * 批量删除小程序图片展示
     * 
     * @param ids 需要删除的小程序图片展示主键
     * @return 结果
     */
    @Override
    public int deleteMallImgShowByIds(Long[] ids)
    {
        return mallImgShowMapper.deleteMallImgShowByIds(ids);
    }

    /**
     * 删除小程序图片展示信息
     * 
     * @param id 小程序图片展示主键
     * @return 结果
     */
    @Override
    public int deleteMallImgShowById(Long id)
    {
        return mallImgShowMapper.deleteMallImgShowById(id);
    }

    @Override
    public MallImgShow selectMallImgShowadpopups() {
        return mallImgShowMapper.selectmallimgshowadpopups();
    }

    @Override
    public MallImgShow selectMallpurchasingnotice() {
        return mallImgShowMapper.selectMallpurchasingnotice();
    }
}
